/*
 * Copyright 2011 Timothy Sparg
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.kilnhg.timsparg.juniorkilndomain;

/**
 *Each annotation record describes a contiguous ordered set (block) of lines in a file at the revision responsible for those lines.
 *
 *   nLines: the size of the block in the number of lines
 *   rev: the revision responsible for the block
 *   sAuthor: the block author's name, as configured in the author's .hgrc
 *
 * @author Tim Sparg
 */
public class Annotation {

    private int nLines;
    private String rev;
    private String sAuthor;

    /**
     * 
     * @return the size of the block in the number of lines
     */
    public int getnLines() {
        return nLines;
    }

    /**
     * Set the size of the block in the number of lines
     * @param nLines 
     */
    public void setnLines(int nLines) {
        this.nLines = nLines;
    }

    /**
     * 
     * @return the revision responsible for the block
     */
    public String getRev() {
        return rev;
    }

    /**
     * Set the revision responsible for the block
     * @param rev 
     */
    public void setRev(String rev) {
        this.rev = rev;
    }

    /**
     * the block author's name, as configured in the author's .hgrc
     * 
     * @return the block author's name
     */
    public String getsAuthor() {
        return sAuthor;
    }

    /**
     * Set the block author's name
     * @param sAuthor 
     */
    public void setsAuthor(String sAuthor) {
        this.sAuthor = sAuthor;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Annotation other = (Annotation) obj;
        if (this.nLines != other.nLines) {
            return false;
        }
        if ((this.rev == null) ? (other.rev != null) : !this.rev.equals(other.rev)) {
            return false;
        }
        if ((this.sAuthor == null) ? (other.sAuthor != null) : !this.sAuthor.equals(other.sAuthor)) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 53 * hash + this.nLines;
        hash = 53 * hash + (this.rev != null ? this.rev.hashCode() : 0);
        hash = 53 * hash + (this.sAuthor != null ? this.sAuthor.hashCode() : 0);
        return hash;
    }
}
