/*
 * Copyright 2011 Timothy Sparg
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.kilnhg.timsparg.juniorkilndomain;

import java.util.List;

/**
 *    bsLines: a list of lines in the file, one bytestring per line
 *  annotations: a list of annotation records (null if the API call took false for "fAnnotate")
 *
 * 
 * @author Tim Sparg
 */
public class Cat {

    private List<String> bsLines;
    private List<Annotation> annotations;

    /**
     * a list of annotation records (null if the API call took false for "fAnnotate")
     * @return a list of annotation records 
     */
    public List<Annotation> getAnnotations() {
        return annotations;
    }

    /**
     * Sets a list of annotation records 
     * @param annotations 
     */
    public void setAnnotations(List<Annotation> annotations) {
        this.annotations = annotations;
    }

    /**
     * a list of lines in the file, one bytestring per line
     * 
     * @return a list of lines in the file
     */
    public List<String> getBsLines() {
        return bsLines;
    }

    /**
     *Sets  a list of lines in the file
     * @param bsLines 
     */
    public void setBsLines(List<String> bsLines) {
        this.bsLines = bsLines;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Cat other = (Cat) obj;
        if (this.bsLines != other.bsLines && (this.bsLines == null || !this.bsLines.equals(other.bsLines))) {
            return false;
        }
        if (this.annotations != other.annotations && (this.annotations == null || !this.annotations.equals(other.annotations))) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 53 * hash + (this.bsLines != null ? this.bsLines.hashCode() : 0);
        hash = 53 * hash + (this.annotations != null ? this.annotations.hashCode() : 0);
        return hash;
    }

    @Override
    public String toString() {
        return "Cat{" + "bsLines=" + bsLines + ", annotations=" + annotations + '}';
    }
}
