/*
 * Copyright 2011 Timothy Sparg
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.kilnhg.timsparg.juniorkilndomain;

import java.util.List;

/**
 *Each diff describes the modifications to exactly one file in a given revision.
 *
 *    bsLines:      the lines of the diff corresponding to a list of bytestrings
 *    file:         a file record about the file modified
 *    bpPath:       the file path
 *    sType:        type of modification ENUM
 *    bpOldPath:    the file path before modification (null unless sType is 
 *                  "rename" or "copy")
 *    modeChange:   a two-element list whose first element is the file mode before 
 *                  modification and whose second element is the file mode after 
 *                  modification (null unless sType is "modechange")
 *
 * @author Tim Sparg
 */
public class Diff {

    private String bsLines;
    private String file;
    private String bpPath;
    private String sType;
    private String bpOldPath;
    private List<String> modeChange;

    
    /**
     * the file path before modification (null unless sType is "rename" or "copy")
     * 
     * @return the file path before modification
     */
    public String getBpOldPath() {
        return bpOldPath;
    }

    /**
     * Sets the file path before modification
     * 
     * @param bpOldPath 
     */
    public void setBpOldPath(String bpOldPath) {
        this.bpOldPath = bpOldPath;
    }

    /**
     * 
     * @return the file path
     */
    public String getBpPath() {
        return bpPath;
    }

    /**
     * Sets the file path
     * @param bpPath 
     */
    public void setBpPath(String bpPath) {
        this.bpPath = bpPath;
    }

    /**
     * 
     * @return the lines of the diff corresponding to a list of bytestrings
     */
    public String getBsLines() {
        return bsLines;
    }

    /**
     * Sets the lines of the diff corresponding to a list of bytestrings
     * @param bsLines 
     */
    public void setBsLines(String bsLines) {
        this.bsLines = bsLines;
    }

    /**
     * 
     * @return a file record about the file modified
     */
    public String getFile() {
        return file;
    }

    /**
     * Sets a file record about the file modified
     * @param file 
     */
    public void setFile(String file) {
        this.file = file;
    }

    /**
     * a two-element list whose first element is the file mode before 
     * modification and whose second element is the file mode after modification 
     * (null unless sType is "modechange")
     * 
     * @return  a two-element list
     */
    public List<String> getModeChange() {
        return modeChange;
    }

    /**
     * Sets  a two-element list
     * @param modeChange 
     */
    public void setModeChange(List<String> modeChange) {
        this.modeChange = modeChange;
    }

    /**
     * 
     * @return type of modification ENUM
     */
    public String getsType() {
        return sType;
    }

    /**
     * Sets type of modification ENUM
     * @param sType 
     */
    public void setsType(String sType) {
        this.sType = sType;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Diff other = (Diff) obj;
        if ((this.bsLines == null) ? (other.bsLines != null) : !this.bsLines.equals(other.bsLines)) {
            return false;
        }
        if ((this.file == null) ? (other.file != null) : !this.file.equals(other.file)) {
            return false;
        }
        if ((this.bpPath == null) ? (other.bpPath != null) : !this.bpPath.equals(other.bpPath)) {
            return false;
        }
        if ((this.sType == null) ? (other.sType != null) : !this.sType.equals(other.sType)) {
            return false;
        }
        if ((this.bpOldPath == null) ? (other.bpOldPath != null) : !this.bpOldPath.equals(other.bpOldPath)) {
            return false;
        }
        if (this.modeChange != other.modeChange && (this.modeChange == null || !this.modeChange.equals(other.modeChange))) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 3;
        hash = 59 * hash + (this.bsLines != null ? this.bsLines.hashCode() : 0);
        hash = 59 * hash + (this.file != null ? this.file.hashCode() : 0);
        return hash;
    }
}
