/*
 * Copyright 2011 Timothy Sparg
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.kilnhg.timsparg.juniorkilndomain;

/**
 *Each manifest record corresponds to exactly one file and describes its location.
 *
 *    bpPath: the path to the file as a byte path (see API Idioms)
 *    sPath: the path to the file in UTF-8 (null if the server was unable to encode it as UTF-8)
 *
 * @author Tim Sparg
 */
public class Manifest {

    private String bpPath;
    private String sPath;

    /**
     * 
     * @return the path to the file as a byte path
     */
    public String getBpPath() {
        return bpPath;
    }

    /**
     * Set the path to the file as a byte path
     * 
     * @param bpPath 
     */
    public void setBpPath(String bpPath) {
        this.bpPath = bpPath;
    }

    /**
     * 
     * @return the path to the file in UTF-8 
     */
    public String getsPath() {
        return sPath;
    }

    /**
     * Set the path to the file in UTF-8 
     * @param sPath 
     */
    public void setsPath(String sPath) {
        this.sPath = sPath;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Manifest other = (Manifest) obj;
        if ((this.bpPath == null) ? (other.bpPath != null) : !this.bpPath.equals(other.bpPath)) {
            return false;
        }
        if ((this.sPath == null) ? (other.sPath != null) : !this.sPath.equals(other.sPath)) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 5;
        hash = 79 * hash + (this.bpPath != null ? this.bpPath.hashCode() : 0);
        hash = 79 * hash + (this.sPath != null ? this.sPath.hashCode() : 0);
        return hash;
    }

    @Override
    public String toString() {
        return "Manifest{" + "bpPath=" + bpPath + ", sPath=" + sPath + '}';
    }
}