/*
 * Copyright 2011 Timothy Sparg
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.kilnhg.timsparg.juniorkilndomain;

/**
 *
 * The permission record contains the following keys:
 *
 *
 * ixPerson: the person the record describes
 * permission: the permission of the person, one of "none", "read", "write", 
 * or "admin" (but not "inherit", because setting a person to "inherit" is the 
 * same as deleting that person's permission record)
 *
 * 
 * @author Tim Sparg
 */
public class Permission {

    private int ixPerson;
    private String permission;

    /**
     * 
     * @return the person ID the record describes
     */
    public int getIxPerson() {
        return ixPerson;
    }

    /**
     * 
     * @param ixPerson The person ID to which the record should relate
     */
    public void setIxPerson(int ixPerson) {
        this.ixPerson = ixPerson;
    }

    /**
     * the permission of the person, one of "none", "read", "write", or "admin"
     * (but not "inherit", because setting a person to "inherit" is the same 
     * as deleting that person's permission record)
     * 
     * @return "none", "read", "write", or "admin"
     */
    public String getPermission() {
        return permission;
    }

    /**
     * Note: the domain object will not complain when an invalid permission
     * is set, however the Kiln API will.
     * 
     * @param "none", "read", "write", or "admin"
     */
    public void setPermission(String permission) {
        this.permission = permission;
    }

    @Override
    public String toString() {
        return "Permission{" + "ixPerson=" + ixPerson + ";permission=" + permission + '}';
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Permission other = (Permission) obj;
        if (this.ixPerson != other.ixPerson) {
            return false;
        }
        if ((this.permission == null) ? (other.permission != null) : !this.permission.equals(other.permission)) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 71 * hash + this.ixPerson;
        hash = 71 * hash + (this.permission != null ? this.permission.hashCode() : 0);
        return hash;
    }
}
