/*
 * Copyright 2011 Timothy Sparg
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.kilnhg.timsparg.juniorkilndomain;

import java.util.List;

/**
 * The project record contains the keys:
 *
 *   ixProject: a unique project identifier
 *   sSlug: a unique project URL slug
 *   sName: the project name
 *   sDescription: the project description
 *   permissionDefault: the default project permission
 *   repoGroups: a list of repository group records belonging to the project
 *
 *
 * @author Tim Sparg
 */
public class Project {

    private int ixProject;
    private String sSlug;
    private String sName;
    private String sDescription;
    private String permissionDefault;
    private List<RepositoryGroup> repoGroups;

    /**
     * 
     * @return a unique project identifier
     */
    public int getIxProject() {
        return ixProject;
    }

    /**
     * Set the unique project identifier.
     * 
     * @param ixProject
     */
    public void setIxProject(int ixProject) {
        this.ixProject = ixProject;
    }

    /**
     * 
     * @return the default project permission
     */
    public String getPermissionDefault() {
        return permissionDefault;
    }

    /**
     * Set the default project permission
     * 
     * @param permissionDefault 
     */
    public void setPermissionDefault(String permissionDefault) {
        this.permissionDefault = permissionDefault;
    }

    /**
     * 
     * @return a list of repository group records belonging to the project
     */
    public List<RepositoryGroup> getRepoGroups() {
        return repoGroups;
    }

    /**
     * Set a a list of repository group records belonging to the project
     * 
     * @param repoGroups 
     */
    public void setRepoGroups(List<RepositoryGroup> repoGroups) {
        this.repoGroups = repoGroups;
    }

    /**
     * 
     * @return the project description
     */
    public String getsDescription() {
        return sDescription;
    }

    /**
     * Sets the project description
     * 
     * @param sDescription 
     */
    public void setsDescription(String sDescription) {
        this.sDescription = sDescription;
    }

    /**
     * 
     * @return the project name
     */
    public String getsName() {
        return sName;
    }

    /**
     * sets the project name
     * 
     * @param sName 
     */
    public void setsName(String sName) {
        this.sName = sName;
    }

    /**
     * 
     * @return unique project URL slug
     */
    public String getsSlug() {
        return sSlug;
    }

    /**
     * Sets unique project URL slug
     * @param sSlug 
     */
    public void setsSlug(String sSlug) {
        this.sSlug = sSlug;
    }

    @Override
    public String toString() {
        return "Project{" + "ixProject=" + ixProject + ";sSlug=" + sSlug
                + ";sName=" + sName + ";sDescription=" + sDescription
                + ";permissionDefault=" + permissionDefault + ";repoGroups="
                + repoGroups + '}';
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Project other = (Project) obj;
        if (this.ixProject != other.ixProject) {
            return false;
        }
        if ((this.sSlug == null) ? (other.sSlug != null) : !this.sSlug.equals(other.sSlug)) {
            return false;
        }
        if ((this.sName == null) ? (other.sName != null) : !this.sName.equals(other.sName)) {
            return false;
        }
        if ((this.sDescription == null) ? (other.sDescription != null) : !this.sDescription.equals(other.sDescription)) {
            return false;
        }
        if ((this.permissionDefault == null) ? (other.permissionDefault != null) : !this.permissionDefault.equals(other.permissionDefault)) {
            return false;
        }
        if (this.repoGroups != other.repoGroups && (this.repoGroups == null || !this.repoGroups.equals(other.repoGroups))) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 67 * hash + this.ixProject;
        return hash;
    }
}
