/*
 * Copyright 2011 Timothy Sparg
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.kilnhg.timsparg.juniorkilndomain;

/**
 *   ixRepoAlias: unique identifier of the alias.
 *   sName: the user-provided name of the alias.
 *   sSlug: the slugified name. This slug must be unique within each project.
 *   ixRepo: the unique identifier of the repository to which the alias is attached.
 *
 * @author Tim Sparg
 */
public class RepositoryAlias {

    private int ixRepoAlias;
    private String sName;
    private String sSlug;
    private int ixRepo;

    /**
     * 
     * @return the unique identifier of the alias.
     */
    public int getIxRepo() {
        return ixRepo;
    }

    /**
     * Sets the  unique identifier of the alias.
     * 
     * @param ixRepo 
     */
    public void setIxRepo(int ixRepo) {
        this.ixRepo = ixRepo;
    }

    /**
     * 
     * @return the unique identifier of the repository to which the alias is attached.
     */
    public int getIxRepoAlias() {
        return ixRepoAlias;
    }

    /**
     * Set the unique identifier of the repository to which the alias is attached.
     * @param ixRepoAlias 
     */
    public void setIxRepoAlias(int ixRepoAlias) {
        this.ixRepoAlias = ixRepoAlias;
    }

    /**
     * 
     * @return the user-provided name of the alias.
     */
    public String getsName() {
        return sName;
    }

    /**
     * Sets the user-provided name of the alias.
     * 
     * @param ixRepoAlias 
     */
    public void setsName(String sName) {
        this.sName = sName;
    }

    /**
     * 
     * @return the slugified name. This slug must be unique within each project.
     */
    public String getsSlug() {
        return sSlug;
    }

    /**
     * Sets the slugified name. This slug must be unique within each project.
     * @param sSlug 
     */
    public void setsSlug(String sSlug) {
        this.sSlug = sSlug;
    }

    @Override
    public String toString() {
        return "RepositoryAlias{" + "ixRepoAlias=" + ixRepoAlias + ";sName="
                + sName + ";sSlug=" + sSlug + ";ixRepo=" + ixRepo + '}';
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final RepositoryAlias other = (RepositoryAlias) obj;
        if (this.ixRepoAlias != other.ixRepoAlias) {
            return false;
        }
        if ((this.sName == null) ? (other.sName != null) : !this.sName.equals(other.sName)) {
            return false;
        }
        if ((this.sSlug == null) ? (other.sSlug != null) : !this.sSlug.equals(other.sSlug)) {
            return false;
        }
        if (this.ixRepo != other.ixRepo) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 3;
        hash = 31 * hash + this.ixRepoAlias;
        hash = 31 * hash + (this.sName != null ? this.sName.hashCode() : 0);
        return hash;
    }
}
