/*
 * Copyright 2011 Timothy Sparg
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.kilnhg.timsparg.juniorkilndomain;

import java.util.List;

/**
 * The repository group record contains the following keys:
 *
 *    ixRepoGroup: a unique repository group identifier
 *    ixProject: the project the repository group belongs to
 *    sSlug: a unique repository group URL slug
 *    sName: the repository group name
 *    repos: a list of repository records belonging to the repository group
 *
 *
 * @author Tim Sparg
 */
public class RepositoryGroup {

    private int ixRepoGroup;
    private int ixProjectGroup;
    private String sSlug;
    private String sName;
    private List<Repository> repos;

    /**
     * 
     * @return the project the repository group belongs to
     */
    public int getIxProjectGroup() {
        return ixProjectGroup;
    }

    /**
     * Sets the project the repository group belongs to
     * 
     * @param ixProjectGroup 
     */
    public void setIxProjectGroup(int ixProjectGroup) {
        this.ixProjectGroup = ixProjectGroup;
    }

    /**
     * 
     * @return a unique repository group identifier
     */
    public int getIxRepoGroup() {
        return ixRepoGroup;
    }

    /**
     * Sets a unique repository group identifier
     * @param ixRepoGroup 
     */
    public void setIxRepoGroup(int ixRepoGroup) {
        this.ixRepoGroup = ixRepoGroup;
    }

    /**
     * 
     * @return a list of repository records belonging to the repository group
     */
    public List<Repository> getRepos() {
        return repos;
    }

    /**
     *Sets a list of repository records belonging to the repository group
     * @param repos 
     */
    public void setRepos(List<Repository> repos) {
        this.repos = repos;
    }

    /**
     * 
     * @return the repository group name
     */
    public String getsName() {
        return sName;
    }

    /**
     * Sets the repository group name
     * @param sName 
     */
    public void setsName(String sName) {
        this.sName = sName;
    }

    /**
     * 
     * @return a unique repository group URL slug
     */
    public String getsSlug() {
        return sSlug;
    }

    /**
     * Sets a unique repository group URL slug
     * @param sSlug 
     */
    public void setsSlug(String sSlug) {
        this.sSlug = sSlug;
    }

    @Override
    public String toString() {
        return "RepositoryGroup{" + "ixRepoGroup=" + ixRepoGroup
                + ";ixProjectGroup=" + ixProjectGroup + ";sSlug=" + sSlug
                + ";sName=" + sName + ";repos=" + repos + '}';
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final RepositoryGroup other = (RepositoryGroup) obj;
        if (this.ixRepoGroup != other.ixRepoGroup) {
            return false;
        }
        if (this.ixProjectGroup != other.ixProjectGroup) {
            return false;
        }
        if ((this.sSlug == null) ? (other.sSlug != null) : !this.sSlug.equals(other.sSlug)) {
            return false;
        }
        if ((this.sName == null) ? (other.sName != null) : !this.sName.equals(other.sName)) {
            return false;
        }
        if (this.repos != other.repos && (this.repos == null || !this.repos.equals(other.repos))) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 3;
        hash = 97 * hash + this.ixRepoGroup;
        hash = 97 * hash + this.ixProjectGroup;
        return hash;
    }
}
