/*
 * Copyright 2011 Timothy Sparg
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.kilnhg.timsparg.juniorkilndomain;

/**
 *    ixReview: a unique review identifier that also doubles as the FogBugz case number for usage in the FogBugz API
 *    ixRepo: the repository to which the review belongs
 *    personOpened: the person record of the person who opened the review
 *    personAssigned: same but for the person who is currently assigned to the review
 *    personResolved: same but for the person who resolved the review
 *    sStatus: the status of the review, one of "approved", "rejected", "wontreview", or "active"
 *    sTitle: the current title of the review
 *    fOpen: true if the review is currently opened, false otherwise
 *
 * 
 * @author Tim Sparg
 */
public class Review {

    private int ixReview;
    private int ixRepo;
    private Person personOpened;
    private Person personAssigned;
    private Person personResolved;
    private String sStatus;
    private String sTitle;
    private boolean fOpen;

    /**
     * 
     * @return true if the review is currently opened, false otherwise
     */
    public boolean isfOpen() {
        return fOpen;
    }

    /**
     * Set true if the review is currently opened, false otherwise
     * @param fOpen 
     */
    public void setfOpen(boolean fOpen) {
        this.fOpen = fOpen;
    }

    /**
     * 
     * @return the repository to which the review belongs
     */
    public int getIxRepo() {
        return ixRepo;
    }

    /**
     * Set the repository to which the review belongs
     * 
     * @param ixRepo 
     */
    public void setIxRepo(int ixRepo) {
        this.ixRepo = ixRepo;
    }

    /**
     * a unique review identifier that also doubles as the FogBugz case number 
     * for usage in the FogBugz API
     * 
     * @return a unique review identifier
     */
    public int getIxReview() {
        return ixReview;
    }

    /**
     * Set  a unique review identifier
     * 
     * @param ixReview 
     */
    public void setIxReview(int ixReview) {
        this.ixReview = ixReview;
    }

    /**
     * 
     * @return person record of the person who assigned the review
     */
    public Person getPersonAssigned() {
        return personAssigned;
    }

    /**
     * Set the person record of the person who assigned the review
     * @param personAssigned 
     */
    public void setPersonAssigned(Person personAssigned) {
        this.personAssigned = personAssigned;
    }

    /**
     * 
     * @return The person record of the person who opened the review
     */
    public Person getPersonOpened() {
        return personOpened;
    }

    /**
     * Set person record of the person who opened the review
     * @param personOpened 
     */
    public void setPersonOpened(Person personOpened) {
        this.personOpened = personOpened;
    }

    /**
     * 
     * @return the person record of the person who resolved the review
     */
    public Person getPersonResolved() {
        return personResolved;
    }

    /**
     * Set the  person record of the person who resolved the review
     * 
     * @param personResolved 
     */
    public void setPersonResolved(Person personResolved) {
        this.personResolved = personResolved;
    }

    /**
     * the status of the review, one of "approved", "rejected", "wontreview", or "active"
     * @return the status of the review
     */
    public String getsStatus() {
        return sStatus;
    }

    /**
     * Set the status of the review
     * 
     * @param sStatus 
     */
    public void setsStatus(String sStatus) {
        this.sStatus = sStatus;
    }

    /**
     * 
     * @return the current title of the review
     */
    public String getsTitle() {
        return sTitle;
    }

    /**
     * Set the current title of the review
     * 
     * @param sTitle 
     */
    public void setsTitle(String sTitle) {
        this.sTitle = sTitle;
    }

    @Override
    public String toString() {
        return "Review{" + "ixReview=" + ixReview + ";ixRepo=" + ixRepo
                + ";personOpened=" + personOpened + ";personAssigned="
                + personAssigned + "personResolved=" + personResolved
                + ";sStatus=" + sStatus + ";sTitle=" + sTitle + "f;Open="
                + fOpen + '}';
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Review other = (Review) obj;
        if (this.ixReview != other.ixReview) {
            return false;
        }
        if (this.ixRepo != other.ixRepo) {
            return false;
        }
        if (this.personOpened != other.personOpened && (this.personOpened == null || !this.personOpened.equals(other.personOpened))) {
            return false;
        }
        if (this.personAssigned != other.personAssigned && (this.personAssigned == null || !this.personAssigned.equals(other.personAssigned))) {
            return false;
        }
        if (this.personResolved != other.personResolved && (this.personResolved == null || !this.personResolved.equals(other.personResolved))) {
            return false;
        }
        if ((this.sStatus == null) ? (other.sStatus != null) : !this.sStatus.equals(other.sStatus)) {
            return false;
        }
        if ((this.sTitle == null) ? (other.sTitle != null) : !this.sTitle.equals(other.sTitle)) {
            return false;
        }
        if (this.fOpen != other.fOpen) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 5;
        hash = 47 * hash + this.ixReview;
        hash = 47 * hash + this.ixRepo;
        return hash;
    }
}
